@@ -1,10 +1,11 @@
+import asyncio
 from unittest.mock import AsyncMock, Mock, patch
 
 import pytest
 from github.GithubException import UnknownObjectException
 from github.PullRequest import PullRequest
 
-from webhook_server.libs.labels_handler import LabelsHandler
+from webhook_server.libs.handlers.labels_handler import LabelsHandler
 from webhook_server.utils.constants import (
     ADD_STR,
     APPROVE_STR,
@@ -128,9 +129,44 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[False, True]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[False, True]
+                ):
                     await labels_handler._add_label(mock_pull_request, "test-label")
                     mock_pull_request.add_to_labels.assert_called_once_with("test-label")
+                    # Verify completion log was called
+                    assert labels_handler.logger.step.called  # type: ignore[attr-defined]
+
+    @pytest.mark.asyncio
+    async def test_add_label_too_long(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
+        """Test _add_label when label is too long (> 49 chars)."""
+        long_label = "a" * 50  # 50 characters
+        await labels_handler._add_label(mock_pull_request, long_label)
+        # Verify label was not added
+        mock_pull_request.add_to_labels.assert_not_called()
+        # Verify completion log was called (label too long is acceptable)
+        assert labels_handler.logger.step.called  # type: ignore[attr-defined]
+
+    @pytest.mark.asyncio
+    async def test_add_label_already_exists(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
+        """Test _add_label when label already exists."""
+        with patch.object(labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, return_value=True):
+            await labels_handler._add_label(mock_pull_request, "existing-label")
+            # Verify label was not added (already exists)
+            mock_pull_request.add_to_labels.assert_not_called()
+            # Verify completion log was called (label already exists is acceptable)
+            assert labels_handler.logger.step.called  # type: ignore[attr-defined]
+
+    @pytest.mark.asyncio
+    async def test_add_label_static_label(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
+        """Test _add_label with static label."""
+        static_label = next(iter(STATIC_LABELS_DICT.keys()))
+        with patch.object(labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, return_value=False):
+            await labels_handler._add_label(mock_pull_request, static_label)
+            # Verify label was added
+            mock_pull_request.add_to_labels.assert_called_once_with(static_label)
+            # Verify completion log was called
+            assert labels_handler.logger.step.called  # type: ignore[attr-defined]
 
     @pytest.mark.asyncio
     async def test_add_label_exception_handling(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
@@ -138,7 +174,9 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[False, True]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[False, True]
+                ):
                     with patch.object(mock_pull_request, "add_to_labels", side_effect=Exception("Test error")):
                         # Should not raise exception - the method should handle it gracefully
                         try:
@@ -153,7 +191,9 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[True, False]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True, False]
+                ):
                     result = await labels_handler._remove_label(mock_pull_request, "test-label")
                     assert result is True
                     mock_pull_request.remove_from_labels.assert_called_once_with("test-label")
@@ -166,7 +206,9 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[True, False]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True, False]
+                ):
                     with patch.object(mock_pull_request, "remove_from_labels", side_effect=Exception("Test error")):
                         result = await labels_handler._remove_label(mock_pull_request, "test-label")
                         assert result is False
@@ -179,8 +221,12 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[True, False]):
-                    with patch.object(labels_handler, "wait_for_label", side_effect=Exception("Wait failed")):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True, False]
+                ):
+                    with patch.object(
+                        labels_handler, "wait_for_label", new_callable=AsyncMock, side_effect=Exception("Wait failed")
+                    ):
                         result = await labels_handler._remove_label(mock_pull_request, "test-label")
                         assert result is False
 
@@ -192,11 +238,43 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[True, False]):
-                    with patch.object(labels_handler, "wait_for_label", side_effect=Exception("Wait failed")):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True, False]
+                ):
+                    with patch.object(
+                        labels_handler, "wait_for_label", new_callable=AsyncMock, side_effect=Exception("Wait failed")
+                    ):
                         result = await labels_handler._remove_label(mock_pull_request, "test-label")
                         assert result is False
 
+    @pytest.mark.asyncio
+    async def test_remove_label_not_exists(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
+        """Test _remove_label when label doesn't exist (acceptable outcome)."""
+        with patch.object(labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, return_value=False):
+            result = await labels_handler._remove_label(mock_pull_request, "non-existent-label")
+            assert result is False
+            # Verify that remove_from_labels was not called (we don't check first to save API calls)
+            mock_pull_request.remove_from_labels.assert_not_called()
+            # Verify completion log was called (label doesn't exist is acceptable)
+            assert labels_handler.logger.step.called  # type: ignore[attr-defined]
+
+    @pytest.mark.asyncio
+    async def test_remove_label_wait_timeout(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
+        """Test _remove_label when removal succeeds but wait_for_label times out."""
+        with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
+            mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
+            with patch("asyncio.sleep", new_callable=AsyncMock):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True, True]
+                ):
+                    # wait_for_label returns False (timeout)
+                    with patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=False):
+                        result = await labels_handler._remove_label(mock_pull_request, "test-label")
+                        assert result is False
+                        mock_pull_request.remove_from_labels.assert_called_once_with("test-label")
+                        # Verify failure log was called (timeout waiting for removal)
+                        assert labels_handler.logger.step.called  # type: ignore[attr-defined]
+
     @pytest.mark.asyncio
     async def test_add_label_dynamic_label_wait_exception(
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
@@ -206,12 +284,19 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[False, True]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[False, True]
+                ):
                     with patch.object(
                         labels_handler.repository, "get_label", side_effect=Exception("Get label failed")
                     ):
                         with patch.object(labels_handler.repository, "create_label"):
-                            with patch.object(labels_handler, "wait_for_label", side_effect=Exception("Wait failed")):
+                            with patch.object(
+                                labels_handler,
+                                "wait_for_label",
+                                new_callable=AsyncMock,
+                                side_effect=Exception("Wait failed"),
+                            ):
                                 # Should not raise exception
                                 try:
                                     await labels_handler._add_label(mock_pull_request, dynamic_label)
@@ -224,7 +309,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test _add_label with exception during wait for static label."""
-        static_label = list(STATIC_LABELS_DICT.keys())[0]
+        static_label = next(iter(STATIC_LABELS_DICT.keys()))
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
@@ -239,7 +324,9 @@ class TestLabelsHandler:
         with patch("timeout_sampler.TimeoutWatch") as mock_timeout:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
-                with patch.object(labels_handler, "label_exists_in_pull_request", side_effect=[True]):
+                with patch.object(
+                    labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, side_effect=[True]
+                ):
                     result = await labels_handler.wait_for_label(mock_pull_request, "test-label", exists=True)
                     assert result is True
 
@@ -252,7 +339,10 @@ class TestLabelsHandler:
             mock_timeout.return_value.remaining_time.side_effect = [10, 10, 0]
             with patch("asyncio.sleep", new_callable=AsyncMock):
                 with patch.object(
-                    labels_handler, "label_exists_in_pull_request", side_effect=Exception("Check failed")
+                    labels_handler,
+                    "label_exists_in_pull_request",
+                    new_callable=AsyncMock,
+                    side_effect=Exception("Check failed"),
                 ):
                     with pytest.raises(Exception, match="Check failed"):
                         await labels_handler.wait_for_label(mock_pull_request, "test-label", exists=True)
@@ -264,8 +354,8 @@ class TestLabelsHandler:
         user = "approver1"  # User in the approvers list
 
         with (
-            patch.object(labels_handler, "_add_label") as mock_add,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
             await labels_handler.label_by_user_comment(
                 pull_request=pull_request, user_requested_label=label_name, remove=False, reviewed_user=user
@@ -280,8 +370,8 @@ class TestLabelsHandler:
         user = "unauthorized_user"  # User not in approvers list
 
         with (
-            patch.object(labels_handler, "_add_label") as mock_add,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
             await labels_handler.label_by_user_comment(
                 pull_request=pull_request, user_requested_label=label_name, remove=False, reviewed_user=user
@@ -297,8 +387,8 @@ class TestLabelsHandler:
         user = "approver1"
 
         with (
-            patch.object(labels_handler, "_remove_label") as mock_remove,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
             await labels_handler.label_by_user_comment(
                 pull_request=pull_request, user_requested_label=label_name, remove=True, reviewed_user=user
@@ -321,9 +411,9 @@ class TestLabelsHandler:
 
         with (
             patch.object(pull_request, "get_labels", return_value=existing_labels),
-            patch.object(labels_handler, "_remove_label") as mock_remove,
-            patch.object(labels_handler, "_add_label") as mock_add,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove,
+            patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
             await labels_handler.add_size_label(pull_request=pull_request)
 
@@ -346,9 +436,9 @@ class TestLabelsHandler:
 
         with (
             patch.object(pull_request, "get_labels", return_value=existing_labels),
-            patch.object(labels_handler, "_remove_label") as mock_remove,
-            patch.object(labels_handler, "_add_label") as mock_add,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove,
+            patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
             await labels_handler.add_size_label(pull_request=pull_request)
 
@@ -386,12 +476,10 @@ class TestLabelsHandler:
 
         # Simulate concurrent add and remove operations
         with (
-            patch.object(labels_handler, "_add_label") as mock_add,
-            patch.object(labels_handler, "_remove_label") as mock_remove,
-            patch.object(labels_handler, "wait_for_label", return_value=True),
+            patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+            patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove,
+            patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True),
         ):
-            import asyncio
-
             # Run concurrent operations
             await asyncio.gather(
                 labels_handler._add_label(pull_request=pull_request, label="bug"),
@@ -409,7 +497,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test _add_label with dynamic label where edit raises exception and label is created."""
-        with patch.object(labels_handler, "label_exists_in_pull_request", return_value=False):
+        with patch.object(labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, return_value=False):
             with patch.object(mock_pull_request, "get_labels", return_value=[]):
                 with patch("asyncio.to_thread") as mock_to_thread:
                     # get_label raises UnknownObjectException, create_label raises Exception
@@ -426,9 +514,9 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test _add_label with dynamic label where edit succeeds."""
-        with patch.object(labels_handler, "label_exists_in_pull_request", return_value=False):
+        with patch.object(labels_handler, "label_exists_in_pull_request", new_callable=AsyncMock, return_value=False):
             with patch.object(mock_pull_request, "get_labels", return_value=[]):
-                with patch.object(labels_handler, "wait_for_label", return_value=True):
+                with patch.object(labels_handler, "wait_for_label", new_callable=AsyncMock, return_value=True):
                     with patch("asyncio.to_thread") as mock_to_thread:
                         # get_label returns label, edit succeeds, add_to_labels succeeds
                         mock_label = Mock()
@@ -445,8 +533,8 @@ class TestLabelsHandler:
         # Mock root_approvers as a list to avoid concatenation error
         with patch.object(labels_handler.owners_file_handler, "root_approvers", []):
             with (
-                patch.object(labels_handler, "_add_label") as mock_add,
-                patch.object(labels_handler, "_remove_label") as mock_remove,
+                patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add,
+                patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove,
             ):
                 await labels_handler.manage_reviewed_by_label(mock_pull_request, APPROVE_STR, ADD_STR, "not_approver")
                 mock_add.assert_not_called()
@@ -470,7 +558,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test manage_reviewed_by_label with commented state."""
-        with patch.object(labels_handler, "_add_label") as mock_add:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
             await labels_handler.manage_reviewed_by_label(mock_pull_request, "commented", ADD_STR, "reviewer1")
             mock_add.assert_called_once()
 
@@ -479,14 +567,14 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test manage_reviewed_by_label with unsupported review state."""
-        with patch.object(labels_handler, "_add_label") as mock_add:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
             await labels_handler.manage_reviewed_by_label(mock_pull_request, "unsupported", ADD_STR, "reviewer1")
             mock_add.assert_not_called()
 
     @pytest.mark.asyncio
     async def test_label_by_user_comment_remove(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
         """Test label_by_user_comment with remove=True for regular label."""
-        with patch.object(labels_handler, "_remove_label") as mock_remove:
+        with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
             await labels_handler.label_by_user_comment(mock_pull_request, "bug", True, "user1")
             mock_remove.assert_called_once_with(pull_request=mock_pull_request, label="bug")
 
@@ -503,7 +591,9 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test label_exists_in_pull_request with exception."""
-        with patch.object(labels_handler, "pull_request_labels_names", side_effect=Exception("Test error")):
+        with patch.object(
+            labels_handler, "pull_request_labels_names", new_callable=AsyncMock, side_effect=Exception("Test error")
+        ):
             with pytest.raises(Exception, match="Test error"):
                 await labels_handler.label_exists_in_pull_request(mock_pull_request, "test-label")
 
@@ -516,8 +606,10 @@ class TestLabelsHandler:
         mock_pull_request.deletions = 5
         existing_size_label = f"{SIZE_LABEL_PREFIX}L"
         with patch.object(labels_handler, "pull_request_labels_names", return_value=[existing_size_label]):
-            with patch.object(labels_handler, "_remove_label", side_effect=Exception("Remove failed")):
-                with patch.object(labels_handler, "_add_label"):
+            with patch.object(
+                labels_handler, "_remove_label", new_callable=AsyncMock, side_effect=Exception("Remove failed")
+            ):
+                with patch.object(labels_handler, "_add_label", new_callable=AsyncMock):
                     with pytest.raises(Exception, match="Remove failed"):
                         await labels_handler.add_size_label(mock_pull_request)
 
@@ -526,7 +618,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test label_by_user_comment for LGTM removal."""
-        with patch.object(labels_handler, "manage_reviewed_by_label") as mock_manage:
+        with patch.object(labels_handler, "manage_reviewed_by_label", new_callable=AsyncMock) as mock_manage:
             await labels_handler.label_by_user_comment(
                 pull_request=mock_pull_request, user_requested_label=LGTM_STR, remove=True, reviewed_user="test-user"
             )
@@ -537,7 +629,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test label_by_user_comment for approve removal."""
-        with patch.object(labels_handler, "manage_reviewed_by_label") as mock_manage:
+        with patch.object(labels_handler, "manage_reviewed_by_label", new_callable=AsyncMock) as mock_manage:
             await labels_handler.label_by_user_comment(
                 pull_request=mock_pull_request, user_requested_label=APPROVE_STR, remove=True, reviewed_user="test-user"
             )
@@ -560,7 +652,7 @@ class TestLabelsHandler:
     @pytest.mark.asyncio
     async def test_label_by_user_comment_lgtm_add(self, labels_handler: LabelsHandler, mock_pull_request: Mock) -> None:
         """Test label_by_user_comment for LGTM addition."""
-        with patch.object(labels_handler, "manage_reviewed_by_label") as mock_manage:
+        with patch.object(labels_handler, "manage_reviewed_by_label", new_callable=AsyncMock) as mock_manage:
             await labels_handler.label_by_user_comment(
                 pull_request=mock_pull_request, user_requested_label=LGTM_STR, remove=False, reviewed_user="test-user"
             )
@@ -571,7 +663,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test label_by_user_comment for other label addition."""
-        with patch.object(labels_handler, "_add_label") as mock_add:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
             await labels_handler.label_by_user_comment(
                 pull_request=mock_pull_request,
                 user_requested_label="other-label",
@@ -585,7 +677,7 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test label_by_user_comment for other label removal."""
-        with patch.object(labels_handler, "_remove_label") as mock_remove:
+        with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
             await labels_handler.label_by_user_comment(
                 pull_request=mock_pull_request,
                 user_requested_label="other-label",
@@ -602,8 +694,8 @@ class TestLabelsHandler:
         # Ensure the owners_file_handler has the expected attributes
         with patch.object(labels_handler.owners_file_handler, "all_pull_request_approvers", ["approver1", "approver2"]):
             with patch.object(labels_handler.owners_file_handler, "root_approvers", ["root-approver"]):
-                with patch.object(labels_handler, "_add_label") as mock_add:
-                    with patch.object(labels_handler, "_remove_label") as mock_remove:
+                with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
+                    with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
                         await labels_handler.manage_reviewed_by_label(
                             pull_request=mock_pull_request,
                             review_state=APPROVE_STR,
@@ -621,8 +713,8 @@ class TestLabelsHandler:
         # Ensure the owners_file_handler has the expected attributes
         with patch.object(labels_handler.owners_file_handler, "all_pull_request_approvers", ["approver1", "approver2"]):
             with patch.object(labels_handler.owners_file_handler, "root_approvers", ["root-approver"]):
-                with patch.object(labels_handler, "_add_label") as mock_add:
-                    with patch.object(labels_handler, "_remove_label") as mock_remove:
+                with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
+                    with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
                         await labels_handler.manage_reviewed_by_label(
                             pull_request=mock_pull_request,
                             review_state=APPROVE_STR,
@@ -643,7 +735,7 @@ class TestLabelsHandler:
             "pull_request": {"user": {"login": "test-user"}},
         }
 
-        with patch.object(labels_handler, "_add_label") as mock_add:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
             await labels_handler.manage_reviewed_by_label(
                 pull_request=mock_pull_request,
                 review_state=LGTM_STR,
@@ -663,8 +755,8 @@ class TestLabelsHandler:
             "pull_request": {"user": {"login": "test-user"}},
         }
 
-        with patch.object(labels_handler, "_add_label") as mock_add:
-            with patch.object(labels_handler, "_remove_label") as mock_remove:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
+            with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
                 await labels_handler.manage_reviewed_by_label(
                     pull_request=mock_pull_request, review_state=LGTM_STR, action=ADD_STR, reviewed_user="other-user"
                 )
@@ -676,8 +768,8 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test manage_reviewed_by_label for changes requested with add action."""
-        with patch.object(labels_handler, "_add_label") as mock_add:
-            with patch.object(labels_handler, "_remove_label") as mock_remove:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
+            with patch.object(labels_handler, "_remove_label", new_callable=AsyncMock) as mock_remove:
                 await labels_handler.manage_reviewed_by_label(
                     pull_request=mock_pull_request,
                     review_state="changes_requested",
@@ -692,37 +784,37 @@ class TestLabelsHandler:
         self, labels_handler: LabelsHandler, mock_pull_request: Mock
     ) -> None:
         """Test manage_reviewed_by_label for commented with add action."""
-        with patch.object(labels_handler, "_add_label") as mock_add:
+        with patch.object(labels_handler, "_add_label", new_callable=AsyncMock) as mock_add:
             await labels_handler.manage_reviewed_by_label(
                 pull_request=mock_pull_request, review_state="commented", action=ADD_STR, reviewed_user="test-user"
             )
             mock_add.assert_called_once()
 
-    def test_wip_or_hold_lables_exists_both(self, labels_handler: LabelsHandler) -> None:
-        """Test wip_or_hold_lables_exists with both WIP and HOLD labels."""
+    def test_wip_or_hold_labels_exists_both(self, labels_handler: LabelsHandler) -> None:
+        """Test wip_or_hold_labels_exists with both WIP and HOLD labels."""
         labels = [WIP_STR, HOLD_LABEL_STR, "other-label"]
-        result = labels_handler.wip_or_hold_lables_exists(labels)
+        result = labels_handler.wip_or_hold_labels_exists(labels)
         assert "Hold label exists." in result
         assert "WIP label exists." in result
 
-    def test_wip_or_hold_lables_exists_hold_only(self, labels_handler: LabelsHandler) -> None:
-        """Test wip_or_hold_lables_exists with only HOLD label."""
+    def test_wip_or_hold_labels_exists_hold_only(self, labels_handler: LabelsHandler) -> None:
+        """Test wip_or_hold_labels_exists with only HOLD label."""
         labels = [HOLD_LABEL_STR, "other-label"]
-        result = labels_handler.wip_or_hold_lables_exists(labels)
+        result = labels_handler.wip_or_hold_labels_exists(labels)
         assert "Hold label exists." in result
         assert "WIP label exists." not in result
 
-    def test_wip_or_hold_lables_exists_wip_only(self, labels_handler: LabelsHandler) -> None:
-        """Test wip_or_hold_lables_exists with only WIP label."""
+    def test_wip_or_hold_labels_exists_wip_only(self, labels_handler: LabelsHandler) -> None:
+        """Test wip_or_hold_labels_exists with only WIP label."""
         labels = [WIP_STR, "other-label"]
-        result = labels_handler.wip_or_hold_lables_exists(labels)
+        result = labels_handler.wip_or_hold_labels_exists(labels)
         assert "WIP label exists." in result
         assert "Hold label exists." not in result
 
-    def test_wip_or_hold_lables_exists_neither(self, labels_handler: LabelsHandler) -> None:
-        """Test wip_or_hold_lables_exists with neither WIP nor HOLD labels."""
+    def test_wip_or_hold_labels_exists_neither(self, labels_handler: LabelsHandler) -> None:
+        """Test wip_or_hold_labels_exists with neither WIP nor HOLD labels."""
         labels = ["other-label1", "other-label2"]
-        result = labels_handler.wip_or_hold_lables_exists(labels)
+        result = labels_handler.wip_or_hold_labels_exists(labels)
         assert result == ""
 
     def test_get_custom_pr_size_thresholds_config_available(self, mock_github_webhook: Mock) -> None:
@@ -929,3 +1021,123 @@ class TestLabelsHandler:
         # Test size label not in custom config - should fall back to static if exists
         # This would be the case where user has custom config but requests a static size
         assert labels_handler._get_label_color("size/XL") == "D93F0B"  # Falls back to STATIC_LABELS_DICT
+
+    def test_get_custom_pr_size_thresholds_with_infinity_float(self, mock_github_webhook: Mock) -> None:
+        """Test custom PR size thresholds with float('inf') threshold."""
+        # Mock config with float("inf") threshold
+        mock_github_webhook.config.get_value.return_value = {
+            "S": {"threshold": 100, "color": "green"},
+            "M": {"threshold": 300, "color": "orange"},
+            "XXL": {"threshold": float("inf"), "color": "red"},
+        }
+
+        labels_handler = LabelsHandler(github_webhook=mock_github_webhook, owners_file_handler=Mock())
+
+        thresholds = labels_handler._get_custom_pr_size_thresholds()
+
+        # Verify infinity threshold is accepted and sorted correctly (should be last)
+        expected = [
+            (100, "S", "008000"),  # green hex
+            (300, "M", "ffa500"),  # orange hex
+            (float("inf"), "XXL", "ff0000"),  # red hex - infinity should be last
+        ]
+        assert thresholds == expected
+        # Verify sorting: infinity should be last
+        assert thresholds[-1][0] == float("inf")
+        assert thresholds[-1][1] == "XXL"
+
+    def test_get_custom_pr_size_thresholds_with_infinity_string(self, mock_github_webhook: Mock) -> None:
+        """Test custom PR size thresholds with string 'inf' threshold (YAML compatibility)."""
+        # Mock config with string "inf" threshold (YAML compatibility)
+        mock_github_webhook.config.get_value.return_value = {
+            "S": {"threshold": 50, "color": "green"},
+            "L": {"threshold": 200, "color": "orange"},
+            "XXL": {"threshold": "inf", "color": "red"},
+        }
+
+        labels_handler = LabelsHandler(github_webhook=mock_github_webhook, owners_file_handler=Mock())
+
+        thresholds = labels_handler._get_custom_pr_size_thresholds()
+
+        # Verify string "inf" is converted to float("inf")
+        expected = [
+            (50, "S", "008000"),  # green hex
+            (200, "L", "ffa500"),  # orange hex
+            (float("inf"), "XXL", "ff0000"),  # red hex - converted from string
+        ]
+        assert thresholds == expected
+        # Verify string "inf" was converted to float("inf")
+        assert thresholds[-1][0] == float("inf")
+        assert isinstance(thresholds[-1][0], float)
+
+    def test_get_custom_pr_size_thresholds_mixed_with_infinity(self, mock_github_webhook: Mock) -> None:
+        """Test custom PR size thresholds with mixed integers and infinity."""
+        # Mock config with mixed thresholds (integers + infinity)
+        mock_github_webhook.config.get_value.return_value = {
+            "XS": {"threshold": 20, "color": "lightgray"},
+            "S": {"threshold": 100, "color": "green"},
+            "XXL": {"threshold": float("inf"), "color": "red"},
+            "M": {"threshold": 300, "color": "orange"},
+        }
+
+        labels_handler = LabelsHandler(github_webhook=mock_github_webhook, owners_file_handler=Mock())
+
+        thresholds = labels_handler._get_custom_pr_size_thresholds()
+
+        # Verify proper sorting (infinity should be last)
+        expected = [
+            (20, "XS", "d3d3d3"),  # lightgray hex
+            (100, "S", "008000"),  # green hex
+            (300, "M", "ffa500"),  # orange hex
+            (float("inf"), "XXL", "ff0000"),  # red hex - infinity should be last
+        ]
+        assert thresholds == expected
+        # Verify sorting correctness: numeric values first, then infinity
+        for i in range(len(thresholds) - 1):
+            assert thresholds[i][0] < thresholds[i + 1][0]
+
+    def test_get_size_with_infinity_threshold(self, mock_github_webhook: Mock) -> None:
+        """Test get_size() method with custom infinity threshold."""
+        # Mock config with infinity threshold
+        mock_github_webhook.config.get_value.return_value = {
+            "S": {"threshold": 100, "color": "green"},
+            "M": {"threshold": 300, "color": "orange"},
+            "XXL": {"threshold": float("inf"), "color": "red"},
+        }
+
+        labels_handler = LabelsHandler(github_webhook=mock_github_webhook, owners_file_handler=Mock())
+
+        # Test various PR sizes
+        test_cases = [
+            (50, 0, "size/S"),  # 50 < 100
+            (150, 0, "size/M"),  # 150 >= 100 but < 300
+            (400, 0, "size/XXL"),  # 400 >= 300 but < inf
+            (1000, 500, "size/XXL"),  # 1500 >= 300 but < inf (extremely large PR)
+            (10000, 5000, "size/XXL"),  # 15000 >= 300 but < inf (huge PR)
+        ]
+
+        for additions, deletions, expected in test_cases:
+            pull_request = Mock(spec=PullRequest)
+            pull_request.additions = additions
+            pull_request.deletions = deletions
+
+            result = labels_handler.get_size(pull_request=pull_request)
+            assert result == expected, (
+                f"Failed for {additions}+{deletions}={additions + deletions}, expected {expected}"
+            )
+
+    def test_get_label_color_with_infinity_threshold(self, mock_github_webhook: Mock) -> None:
+        """Test _get_label_color() with custom infinity threshold."""
+        # Mock config with infinity threshold
+        mock_github_webhook.config.get_value.return_value = {
+            "S": {"threshold": 100, "color": "green"},
+            "M": {"threshold": 300, "color": "orange"},
+            "XXL": {"threshold": float("inf"), "color": "red"},
+        }
+
+        labels_handler = LabelsHandler(github_webhook=mock_github_webhook, owners_file_handler=Mock())
+
+        # Verify color is returned correctly for infinity category
+        assert labels_handler._get_label_color("size/S") == "008000"  # green hex
+        assert labels_handler._get_label_color("size/M") == "ffa500"  # orange hex
+        assert labels_handler._get_label_color("size/XXL") == "ff0000"  # red hex (infinity category)
