@@ -1,5 +1,6 @@
+from collections.abc import Callable
 from concurrent.futures import ThreadPoolExecutor
-from typing import Any, Callable
+from typing import Any
 
 from github.Hook import Hook
 
@@ -10,7 +11,7 @@ from webhook_server.utils.helpers import (
     get_logger_with_params,
 )
 
-LOGGER = get_logger_with_params(name="webhook")
+LOGGER = get_logger_with_params()
 
 
 def process_github_webhook(
@@ -31,7 +32,7 @@ def process_github_webhook(
     if not repo:
         return False, f"[API user {api_user}] - Could not find repository {full_repository_name}", LOGGER.error
 
-    config_: dict[str, str] = {"url": f"{webhook_ip}/webhook_server", "content_type": "json"}
+    config_: dict[str, str] = {"url": webhook_ip, "content_type": "json"}
 
     if secret:
         config_["secret"] = secret
